Ryan Delaney (@RDelaney): "Self-acceptance is arguably the hardest practice on the spiritual path. And the most beneficial. Nothing will transform your life more than becoming your own best friend." | nitter
Description: Self-acceptance is arguably the hardest practice on the spiritual path. And the most beneficial. Nothing will transform your life more than becoming your own best friend.

Ryan Delaney
@RDelaney
Jul 14
Self-acceptance is arguably the hardest practice on the spiritual path. And the most beneficial. Nothing will transform your life more than becoming your own best friend.

Jul 14, 2023 · 4:58 PM UTC

11
2
37
martyna @martyna_io
Jul 14
Replying to @RDelaney
You can be your own biggest enemy or greatest ally. Subconsciously we often tend to be the first but we can switch to the latter with awareness, attention and practice.
1
1
Ryan Delaney
@RDelaney
Jul 14
Right, Martyna, a lot of healing, forgiveness, and compassion. At least in my experience.
Haley McArdle @haleynmcardle
Jul 14
Replying to @RDelaney
☺️😇🥰💘
1
1
Ryan Delaney
@RDelaney
Jul 14
🤗💖☀️
Brent Bowlby @BrentBowlby
Jul 14
Replying to @RDelaney
A lot of people only had themselves as their best friend. This is especially hard for children with ASD. Looking people in the eye when speaking w/ each other shows engagement. ASD Kids have a hard time w/this, doesn't mean they don't need friends or can't be engaged.
1
1
Ryan Delaney
@RDelaney
Jul 14
I trust what you say about ASD.
1
1
more replies
Kai
@edge_of_obsess
Jul 14
Replying to @RDelaney
Treat yourself as a friend. Life will be fun after that.
1
Ryan Delaney
@RDelaney
Jul 14
Easy to say, right? And even when we do, life isn't all fun. But infinitely easier.
Sophia Feinbaum @sophiafeinbaum
Jul 14
Replying to @RDelaney
It's so hard! I think we have to overcome a lot of negative conditioning to get there!
1
1
Ryan Delaney
@RDelaney
Jul 14
So much negative conditioning, Sophia. I'm with you.
1
Load more